io.randomseed.utils.set

Random Utilities, set support functions.

Random Utilities, set support functions.
raw docstring

differenceclj

(difference)
(difference of)
(difference of what)
(difference of xform what)

Like clojure.set/difference but optimized with transients and supports an optional transducer xform.

Like `clojure.set/difference` but optimized with transients and supports an
optional transducer `xform`.
sourceraw docstring

out-ofclj

(out-of)
(out-of of)
(out-of of what)
(out-of of xform what)

Removes elements of what from set of. Uses difference when both are sets, otherwise falls back to transient-based disj.

Removes elements of `what` from set `of`. Uses `difference` when both are sets,
otherwise falls back to transient-based `disj`.
sourceraw docstring

replace-inclj

(replace-in s old-val new-val)

Replaces old-val with new-val in set s.

Replaces `old-val` with `new-val` in set `s`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries