Random Utilities, set support functions.
Random Utilities, set support functions.
(difference)(difference of)(difference of what)(difference of xform what)Like clojure.set/difference but optimized with transients and supports an
optional transducer xform.
Like `clojure.set/difference` but optimized with transients and supports an optional transducer `xform`.
(out-of)(out-of of)(out-of of what)(out-of of xform what)Removes elements of what from set of. Uses difference when both are sets,
otherwise falls back to transient-based disj.
Removes elements of `what` from set `of`. Uses `difference` when both are sets, otherwise falls back to transient-based `disj`.
(replace-in s old-val new-val)Replaces old-val with new-val in set s.
Replaces `old-val` with `new-val` in set `s`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |